pub struct CreateAllowlistIdentifierRequest {
pub identifier: String,
pub notify: Option<bool>,
}Fields
identifier: StringThe identifier to be added in the allow-list. This can be an email address, a phone number or a web3 wallet.
notify: Option<bool>This flag denotes whether the given identifier will receive an invitation to join the application. Note that this only works for email address and phone number identifiers.
Implementations
Sourceimpl CreateAllowlistIdentifierRequest
impl CreateAllowlistIdentifierRequest
pub fn new(identifier: String) -> CreateAllowlistIdentifierRequest